@@ -8,8 +8,8 @@ time_features_mapping = {"year_week":"weekofyear",
                          "month_day":"day",
                          "week_day":"dayofweek"}
 
-def compute_train_features(data, ts_uid_columns, time_features, lags, window_sizes, 
-                           window_functions, ignore_const_cols=True):
+def compute_train_features(data, ts_uid_columns, time_features, lags, window_shifts,
+                           window_sizes, window_functions, ignore_const_cols=True):
     """
     Parameters
     ----------
@@ -21,6 +21,8 @@ def compute_train_features(data, ts_uid_columns, time_features, lags, window_siz
         Time attributes to include as features.
     lags: list
         List of integer lag values to include as features.
+    window_shifts: list
+        List of integer window shift values.
     window_sizes: list
         List of integer window sizes values to include as features.
     window_functions: list
@@ -59,6 +61,7 @@ def compute_train_features(data, ts_uid_columns, time_features, lags, window_siz
     if (len(window_sizes) > 0) & (len(window_functions) > 0):
         rw_features = (compute_rw_features(data, 
                                            ts_uid_columns,
+                                           window_shifts=window_shifts,
                                            window_sizes=window_sizes, 
                                            window_functions=window_functions)
                         .merge(data.loc[:, ["ds"]+ts_uid_columns], 
@@ -72,8 +75,8 @@ def compute_train_features(data, ts_uid_columns, time_features, lags, window_siz
     all_features.reset_index(inplace=True)
     return all_features
 
-def compute_predict_features(data, ts_uid_columns, time_features, lags, window_sizes, 
-                             window_functions, ignore_const_cols=True):
+def compute_predict_features(data, ts_uid_columns, time_features, lags, window_shifts,
+                             window_sizes, window_functions, ignore_const_cols=True):
     """
     Parameters
     ----------
@@ -85,6 +88,8 @@ def compute_predict_features(data, ts_uid_columns, time_features, lags, window_s
         Time attributes to include as features.
     lags: list
         List of integer lag values to include as features.
+    window_shifts: list
+        List of integer window shift values.
     window_sizes: list
         List of integer window sizes values to include as features.
     window_functions: list
@@ -108,13 +113,14 @@ def compute_predict_features(data, ts_uid_columns, time_features, lags, window_s
         all_features_list.append(calendar_features.set_index(["ds"]))
 
     if len(lags) > 0:
-        column_names = [f"lag_{lag}" for lag in lags]
+        column_names = [f"lag{lag}" for lag in lags]
         lag_features = pd.DataFrame(np.nan, index=data.ds, 
                                     columns=column_names)
         all_features_list.append(lag_features)
 
     if (len(window_sizes) > 0) & (len(window_functions) > 0):
-        column_names = [f"{window_func}_{window}"
+        column_names = [f"{window_func}{window}_shift{window_shift}"
+                        for window_shift in window_shifts
                         for window_func in window_functions
                         for window in window_sizes]
         rw_features = pd.DataFrame(np.nan, index=data.ds,
@@ -223,19 +229,21 @@ def compute_lag_features(data, ts_uid_columns, lags):
 
     lag_features = data.loc[:, ["ds","y"]+ts_uid_columns].copy(deep=True)
     for lag in lags:
-        feature_name = f"lag_{lag}"
+        feature_name = f"lag{lag}"
         feature_value = lag_features.groupby(ts_uid_columns)["y"].shift(lag).values
         lag_features[feature_name] = feature_value 
     lag_features.drop("y", axis=1, inplace=True)
 
     return lag_features
 
-def compute_rw_features(data, ts_uid_columns, window_sizes, window_functions):
+def compute_rw_features(data, ts_uid_columns, window_shifts, window_sizes, window_functions):
     """
     data: pandas.Dataframe
         dataframe with column 'y' (response values)
     ts_uid_columns: list
         List of columns names that are unique identifiers for time series.
+    window_shifts: list
+        List of integer window shift values.
     window_sizes: list
         list of integer window sizes values
     window_functions: list
@@ -245,12 +253,14 @@ def compute_rw_features(data, ts_uid_columns, window_sizes, window_functions):
     # assert window functions in availabe funcs...
 
     rw_features = data.loc[:, ["ds","y"]+ts_uid_columns].copy(deep=True)
-    rw_features["y"] = rw_features.groupby(ts_uid_columns)["y"].shift(1)
-    for window_func in window_functions:
-        for window in window_sizes:
-            feature_name = f"{window_func}_{window}"
-            feature_value = getattr(rw_features.groupby(ts_uid_columns)["y"].rolling(window), window_func).__call__().values
-            rw_features[feature_name] = feature_value
-    rw_features.drop("y", axis=1, inplace=True)
+    for window_shift in window_shifts:
+        rw_features["ys"] = rw_features.groupby(ts_uid_columns)["y"].shift(window_shift)
+        for window_func in window_functions:
+            for window in window_sizes:
+                feature_name = f"{window_func}{window}_shift{window_shift}"
+                rolling = rw_features.groupby(ts_uid_columns)["ys"].rolling(window)
+                feature_value = getattr(rolling, window_func).__call__().values
+                rw_features[feature_name] = feature_value
+    rw_features.drop(["y","ys"], axis=1, inplace=True)
 
-    return rw_features
+    return rw_features
\ No newline at end of file
